@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,8 @@ private:
 	XMLNamespace();
 
 public:
-	static const std::string DublinCore;
+	static const std::string DublinCorePrefix;
+	static const std::string DublinCoreLegacyPrefix;
 	static const std::string XLink;
 };
 
