@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include "FootnoteView.h"
 #include "ContentsView.h"
 #include "CollectionView.h"
-#include "RecentBooksView.h"
 #include "RecentBooksPopupData.h"
 #include "BookInfoDialog.h"
 #include "TimeUpdater.h"
@@ -113,15 +112,13 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	myFootnoteView = new FootnoteView(*this, context());
 	myContentsView = new ContentsView(*this, context());
 	myCollectionView = new CollectionView(*this, context());
-	myRecentBooksView = new RecentBooksView(*this, context());
 	myRecentBooksPopupData = new RecentBooksPopupData(*this);
 	myMode = UNDEFINED_MODE;
 	myPreviousMode = BOOK_TEXT_MODE;
 	setMode(BOOK_TEXT_MODE);
 
 	addAction(ActionCode::SHOW_READING, new UndoAction(*this, FBReader::BOOK_COLLECTION_MODE | FBReader::CONTENTS_MODE | FBReader::FOOTNOTE_MODE));
-	addAction(ActionCode::SHOW_COLLECTION, new SetModeAction(*this, FBReader::BOOK_COLLECTION_MODE, FBReader::BOOK_TEXT_MODE | FBReader::RECENT_BOOKS_MODE));
-	//addAction(ActionCode::SHOW_LAST_BOOKS, new SetModeAction(*this, FBReader::RECENT_BOOKS_MODE, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE));
+	addAction(ActionCode::SHOW_COLLECTION, new SetModeAction(*this, FBReader::BOOK_COLLECTION_MODE, FBReader::BOOK_TEXT_MODE));
 	addAction(ActionCode::SHOW_OPTIONS, new ShowOptionsDialogAction(*this));
 	addAction(ActionCode::SHOW_CONTENTS, new ShowContentsAction(*this));
 	addAction(ActionCode::SHOW_BOOK_INFO, new ShowBookInfoAction(*this));
@@ -389,10 +386,6 @@ void FBReader::setMode(ViewMode mode) {
 			collectionView().openWithBook((myModel != 0) ? myModel->description() : 0);
 			setView(myCollectionView);
 			break;
-		case RECENT_BOOKS_MODE:
-			((RecentBooksView&)*myRecentBooksView).rebuild();
-			setView(myRecentBooksView);
-			break;
 		case BOOKMARKS_MODE:
 			break;
 		case UNDEFINED_MODE:
@@ -450,7 +443,6 @@ void FBReader::clearTextCaches() {
 	((ZLTextView&)*myFootnoteView).clearCaches();
 	((ZLTextView&)*myContentsView).clearCaches();
 	((ZLTextView&)*myCollectionView).clearCaches();
-	((ZLTextView&)*myRecentBooksView).clearCaches();
 }
 
 shared_ptr<ZLKeyBindings> FBReader::keyBindings() {
