@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2008 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #include <cctype>
 
+#include <ZLFile.h>
 #include <ZLFileImage.h>
 #include <ZLStringUtil.h>
 
@@ -170,11 +171,14 @@ void HtmlImageTagAction::run(const HtmlReader::HtmlTag &tag) {
 		bookReader().endParagraph();
 		for (unsigned int i = 0; i < tag.Attributes.size(); ++i) {
 			if (tag.Attributes[i].Name == "SRC") {
-				std::string fileName = MiscUtil::decodeHtmlURL(tag.Attributes[i].Value);
-				bookReader().addImageReference(fileName);
-				bookReader().addImage(fileName,
-					new ZLFileImage("image/auto", myReader.myBaseDirPath + fileName, 0)
-				);
+				const std::string fileName = MiscUtil::decodeHtmlURL(tag.Attributes[i].Value);
+				const std::string filePath = myReader.myBaseDirPath + fileName;
+				if (ZLFile(filePath).exists()) {
+					bookReader().addImageReference(fileName);
+					bookReader().addImage(fileName,
+						new ZLFileImage("image/auto", filePath, 0)
+					);
+				}
 				break;
 			}
 		}
@@ -539,7 +543,18 @@ bool HtmlBookReader::characterDataHandler(const char *text, size_t len, bool con
 		}
 	}
 	if (myIsStarted) {
-		addConvertedDataToBuffer(ptr, end - ptr, convert);
+		for (const char *p = ptr; p < end - 2; ++p) {
+			if ((*p == '\n') && (*(p + 2) == '\n')) {
+				addConvertedDataToBuffer(ptr, p - ptr, convert);
+				myBookReader.endParagraph();
+				myBookReader.beginParagraph();
+				p += 2;
+				ptr = p + 1;
+			}
+		}
+		if (ptr < end) {
+			addConvertedDataToBuffer(ptr, end - ptr, convert);
+		}
 	}
 	return true;
 }
